# BetterEntryPreview.pl
# Better Entry Preview plugin for Movable Type
# http://www.danandsherree.com/2005/09/01/better_entry_preview.php
# by Dan Wolfgang
# http://www.danandsherree.com/
# last modified 9/24/05

use strict;
package MT::Plugin::BetterEntryPreview;

use vars qw( $VERSION );
$VERSION = '1.01';

require MT;
require MT::Plugin;



#These are the default styles. Just something to get started with.
my $style = qq{<style>
#bep_content{}
.right {float: right; margin: 20px 0 20px 20px;}
.left {float: left; margin: 20px 20px 20px 0;}

p, li {font-size: 1.2em; line-height: 2em; margin: 1.5em 0; font-family: Georgia, serif;}
h1, h2, h3, h4, h5, h6 {color: black;}
h1 {font-size: 2.5em;}
h2 {font-size: 2em;}
h3 {font-size: 1.7em;}
</style>};


my $settings;
eval {
	$settings = new MT::PluginSettings([
		['BEP_style', { Default => $style }],
		['system_override', { Default => 0 }]
	]);
};


my $plugin = MT::Plugin->new({
	name => "Better Entry Preview",
	description => 'Update the entry preview window to display friendlier.',
	doc_link => 'http://www.danandsherree.com/2005/09/01/better_entry_preview.php',
	author_name => 'Dan Wolfgang',
	author_link => 'http://www.danandsherree.com',
	version => $VERSION,
	config_template => \&_config_template,
	settings => $settings
});

MT->add_plugin($plugin);

MT->add_callback('bigpapi::template::preview_entry', 9, $plugin, \&_template);
MT->add_callback('bigpapi::param::preview_entry', 9, $plugin, \&_param);




# Draw the config window, with a textarea for changing the styles.
sub _config_template {
	my ($plugin, $param, $scope) = @_;
	my $html = '';
	if ($scope eq 'system') {
		$html .= <<HTML;
<div class="setting">
<div class="field">
<p><input value="1" type="checkbox" name="system_override" id="system_override" <TMPL_IF NAME=SYSTEM_OVERRIDE>checked="checked"</TMPL_IF> />
<MT_TRANS phrase="Override weblog-specific settings with the settings below:"></p>
</div>
</div>
HTML
	}
    $html .= <<HTML;
<div class="setting">
<div class="field">
<p>How should the preview page look? Edit the CSS to your liking.</p>
<textarea columns="50" rows="10" name="BEP_style" id="BEP_style"><TMPL_VAR NAME=BEP_STYLE></textarea>
</div> 
</div>
HTML
	return $html;
}


sub blog_config {
	my ($blog_id) = @_;
	my $sys = $plugin->get_config_hash('system');
	if ($sys->{'system_override'}) {
		return $sys;
	} else {
		return $plugin->get_config_hash('blog:' . $blog_id);
	}
}


# Make the style into an HTML::Template variable.
sub _param {
	my ($cb, $app, $param) = @_;

	my $config = blog_config($param->{'blog_id'});

	$param->{BEP_STYLE} = $config->{'BEP_style'};
}

# Rewrite the entry preview screen, integrating the new styles.
sub _template {
	my ($cb, $app, $template) = @_;
	my $old = qq{<TMPL_VAR NAME=PREVIEW_BODY>};
	$old = quotemeta($old);
	
	my $new = <<HTML;
<TMPL_VAR NAME=BEP_STYLE>
<div id="bep_content">
<TMPL_VAR NAME=PREVIEW_BODY>
</div>
HTML
	$$template =~ s/$old/$new/;
}

1;
